==> guikachu-0.9.tar.gz: guikachu-0.9/src/form-editor/checkbox.h <==
//$Id: checkbox.h,v 1.5 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_CHECKBOX_H
#define GUIKACHU_FORM_EDITOR_CHECKBOX_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>
#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Checkbox;
    }
}

#include "resizeable.h"
#include "textual.h"

#include "checkbox-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Checkbox: public Widget,
			public Resizeable,
			public Textual
	{
	    GUI::FormEditor::CheckboxProperties *editor;

	    class GroupProp: public Property<int>
	    {
		Checkbox *owner;
	    public:
		GroupProp (Checkbox *owner);
		virtual void set_val (const int& value);
		inline const int& operator= (const int& value_) { set_val (value_); return value; };
	    };
	    
	    class ToggledProp: public Property<bool>
	    {
		Checkbox *owner;
	    public:
		ToggledProp (Checkbox *owner);
		virtual void set_val (const bool& value);
		inline const bool& operator= (const bool& value_) { set_val (value_); return value; };
	    };
	    
	public:
	    Checkbox (Resources::Form *owner,
		      const string& id);
	    virtual ~Checkbox ();
	    
	    virtual Type get_type () const { return WIDGET_CHECKBOX; };
	    
	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget *get_editor ();

	    virtual int get_display_width ();
	    virtual int get_display_height ();

	    Property<bool>   usable;
	    Property<bool>   anchor_right;
	    GroupProp        group;
	    ToggledProp      toggled;
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
	    virtual void save (xmlNodePtr node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_CHECKBOX_H */

==> guikachu-0.10.tar.gz: guikachu-0.10/src/form-editor/checkbox.h <==
//$Id: checkbox.h,v 1.8 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_CHECKBOX_H
#define GUIKACHU_FORM_EDITOR_CHECKBOX_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>
#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Checkbox;
    }
}

#include "resizeable.h"
#include "textual.h"

#include "checkbox-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Checkbox: public Widget,
			public Resizeable,
			public Textual
	{
	    GUI::FormEditor::CheckboxProperties *editor;

	    class GroupProp: public Property<int>
	    {
		Checkbox *owner;
	    public:
		GroupProp (Checkbox *owner);
		virtual void set_val (const int& value);
		inline const int& operator= (const int& value_) { set_val (value_); return value; };
	    };
	    
	    class ToggledProp: public Property<bool>
	    {
		Checkbox *owner;
	    public:
		ToggledProp (Checkbox *owner);
		virtual void set_val (const bool& value);
		inline const bool& operator= (const bool& value_) { set_val (value_); return value; };
	    };
	    
	public:
	    Checkbox (Resources::Form *owner,
		      const string& id);
	    virtual ~Checkbox ();
	    
	    virtual Type get_type () const { return WIDGET_CHECKBOX; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();

	    virtual int get_display_width ();
	    virtual int get_display_height ();

	    Property<bool>   usable;
	    Property<bool>   anchor_right;
	    GroupProp        group;
	    ToggledProp      toggled;
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_CHECKBOX_H */
